@@ -240,7 +240,7 @@ void LocationFilter::Save(DataWriter &out) const
 			out.BeginChild();
 			{
 				for(const Government *government : governments)
-					out.Write(government->GetTrueName());
+					out.Write(government->TrueName());
 			}
 			out.EndChild();
 		}
